==> webcamoid_9.0.0.orig.tar.xz: webcamoid-9.0.0/README.md <==
# Webcamoid, The ultimate webcam suite! #

[Webcamoid](https://webcamoid.github.io/) is a full featured and multiplatform webcam suite.

<a target="_blank" href="https://webcamoid.github.io/"><img src="https://webcamoid.github.io/theme/images/screenshots/Main.png" style="height: 240px;" /></a>

## Features ##

* Cross-platform (GNU/Linux, Mac, Windows)
* Take pictures and record videos with the webcam.
* Manages multiple webcams.
* Written in C++ and Qt.
* Custom controls for each webcam.
* Add funny effects to the webcam.
* 60+ effects available.
* Translated to many languages.
* Use custom network and local files as capture devices.
* Capture from desktop.
* Many recording formats.
* Virtual webcam support for feeding other programs.

## Build and Install ##

Visit the [wiki](https://github.com/webcamoid/webcamoid/wiki) for a comprehensive compile and install instructions.

## Downloads ##

[![Download](https://img.shields.io/badge/Download-Releases-3f2a7e.svg)](https://github.com/webcamoid/webcamoid/releases)
[![Daily Build](https://img.shields.io/badge/Download-Daily%20Build-3f2a7e.svg)](https://github.com/webcamoid/webcamoid/releases/tag/daily-build)
[![Total Downloads](https://img.shields.io/github/downloads/webcamoid/webcamoid/total.svg?label=Total%20Downloads&color=3f2a7e)](https://tooomm.github.io/github-release-stats/?username=webcamoid&repository=webcamoid)

## Donations ##

Any donation amount is welcome and very appreciated.

[![Patreon](https://img.shields.io/badge/Donate-Patreon-7f7f00.svg)](https://www.patreon.com/hipersayanx)
[![Ko-fi](https://img.shields.io/badge/Donate-Ko%20fi-7f7f00.svg)](https://ko-fi.com/hipersayanx)
[![Liberapay](https://img.shields.io/badge/Donate-Liberapay-7f7f00.svg)](https://liberapay.com/hipersayanx)
[![Paypal](https://img.shields.io/badge/Donate-Paypal-7f7f00.svg)](https://www.paypal.me/WebcamoidDonations)
[![Coinbase](https://img.shields.io/badge/Donate-Coinbase-7f7f00.svg)](https://commerce.coinbase.com/checkout/e5396fdc-119a-4287-bab9-383ea6332cdc)
[![Monero](https://img.shields.io/badge/Donate-Monero-7f7f00.svg)](https://gist.github.com/hipersayanX/0d575fc7b9b36a2e9817027fb50258bd)

## Status ##

[![Android](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml)
[![Arch Linux](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml)
[![Debian](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml)
[![Fedora](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml)
[![Mageia](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml)
[![Linux MinGW](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml)
[![OpenSUSE](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml)
[![Ubuntu](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml)
[![Mac](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml)
[![Windows MSYS](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml)
[![Build status](https://ci.appveyor.com/api/projects/status/1ecp839l0nnnya9l?svg=true)](https://ci.appveyor.com/project/hipersayanX/webcamoid)
[![Build status](https://api.cirrus-ci.com/github/webcamoid/webcamoid.svg)](https://cirrus-ci.com/github/webcamoid/webcamoid)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/08a585dc07a14b8bad2bbb39d6628fdd)](https://www.codacy.com/gh/webcamoid/webcamoid/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=webcamoid/webcamoid&amp;utm_campaign=Badge_Grade)
[![Translation status](https://hosted.weblate.org/widgets/webcamoid/-/svg-badge.svg)](https://hosted.weblate.org/engage/webcamoid/?utm_source=widget)
[![Project Stats](https://www.openhub.net/p/Webcamoid/widgets/project_thin_badge.gif)](https://www.openhub.net/p/Webcamoid)
[![Gitlab mirror](https://img.shields.io/badge/mirror-Gitlab-007fff.svg)](https://gitlab.com/hipersayanX/webcamoid/)
[![SourceForge mirror](https://img.shields.io/badge/mirror-SourceForge-007fff.svg)](https://sourceforge.net/p/webcamoid/)

[![Packaging status](https://repology.org/badge/vertical-allrepos/webcamoid.svg)](https://repology.org/metapackage/webcamoid)

## License ##

```
Webcamoid is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Webcamoid is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
```

[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](https://github.com/webcamoid/webcamoid/blob/master/COPYING)

## Reporting Bugs ##

Report all issues in the [issues tracker](https://github.com/webcamoid/webcamoid/issues).

## Subscribe ##

Stay tuned to new releases with the project [feeds](https://github.com/webcamoid/webcamoid/releases.atom).

==> webcamoid_9.1.1.orig.tar.xz: webcamoid-9.1.1/README.md <==
# Webcamoid, The ultimate webcam suite! #

[Webcamoid](https://webcamoid.github.io/) is a full featured and multiplatform webcam suite.

<a target="_blank" href="https://webcamoid.github.io/"><img src="https://webcamoid.github.io/theme/images/screenshots/Main.webp" style="height: 240px;" /></a>

## Features ##

* Cross-platform (GNU/Linux, Mac, Windows)
* Take pictures and record videos with the webcam.
* Manages multiple webcams.
* Written in C++ and Qt.
* Custom controls for each webcam.
* Add funny effects to the webcam.
* 60+ effects available.
* Translated to many languages.
* Use custom network and local files as capture devices.
* Capture from desktop.
* Many recording formats.
* Virtual webcam support for feeding other programs.

## Build and Install ##

Visit the [wiki](https://github.com/webcamoid/webcamoid/wiki) for a comprehensive compile and install instructions.

## Downloads ##

[![Download](https://img.shields.io/badge/Download-Releases-3f2a7e.svg)](https://github.com/webcamoid/webcamoid/releases)
[![Daily Build](https://img.shields.io/badge/Download-Daily%20Build-3f2a7e.svg)](https://github.com/webcamoid/webcamoid/releases/tag/daily-build)
[![Total Downloads](https://img.shields.io/github/downloads/webcamoid/webcamoid/total.svg?label=Total%20Downloads&color=3f2a7e)](https://tooomm.github.io/github-release-stats/?username=webcamoid&repository=webcamoid)

## Donations ##

If you are interested in donating to the project you can look at all available methods in the [donations page](https://webcamoid.github.io/donations).

## Status ##

[![Android](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml)
[![Arch Linux](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml)
[![Debian](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml)
[![Fedora](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml)
[![Mageia](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml)
[![Linux MinGW](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml)
[![OpenSUSE](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml)
[![Ubuntu](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml)
[![Flatpak](https://github.com/webcamoid/webcamoid/actions/workflows/flatpak.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/flatpak.yml)
[![Mac](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml)
[![Windows MSYS](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml)
[![Build status](https://ci.appveyor.com/api/projects/status/1ecp839l0nnnya9l?svg=true)](https://ci.appveyor.com/project/hipersayanX/webcamoid)
[![Build status](https://api.cirrus-ci.com/github/webcamoid/webcamoid.svg)](https://cirrus-ci.com/github/webcamoid/webcamoid)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/08a585dc07a14b8bad2bbb39d6628fdd)](https://www.codacy.com/gh/webcamoid/webcamoid/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=webcamoid/webcamoid&amp;utm_campaign=Badge_Grade)
[![Translation status](https://hosted.weblate.org/widgets/webcamoid/-/svg-badge.svg)](https://hosted.weblate.org/engage/webcamoid/?utm_source=widget)
[![Project Stats](https://www.openhub.net/p/Webcamoid/widgets/project_thin_badge.gif)](https://www.openhub.net/p/Webcamoid)
[![Gitlab mirror](https://img.shields.io/badge/mirror-Gitlab-007fff.svg)](https://gitlab.com/hipersayanX/webcamoid/)
[![SourceForge mirror](https://img.shields.io/badge/mirror-SourceForge-007fff.svg)](https://sourceforge.net/p/webcamoid/)

[![Packaging status](https://repology.org/badge/vertical-allrepos/webcamoid.svg)](https://repology.org/metapackage/webcamoid)

## License ##

```
Webcamoid is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Webcamoid is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
```

[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](https://github.com/webcamoid/webcamoid/blob/master/COPYING)

## Reporting Bugs ##

Report all issues in the [issues tracker](https://github.com/webcamoid/webcamoid/issues).

## Subscribe ##

Stay tuned to new releases with the project [feeds](https://github.com/webcamoid/webcamoid/releases.atom).
